'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');

const ReduxStore = Symbol('redux');

const useStore = () => vue.inject(ReduxStore);

const useSelector = (select, equalityFn = (nextState, currentState) => nextState === currentState) => {
  const {
    subscribe,
    getState
  } = useStore();
  const selector = vue.ref(select(getState()));
  let currentState;
  const unsubscribe = subscribe(() => {
    const nextState = select(getState());

    if (!equalityFn(nextState, currentState)) {
      currentState = nextState;
      selector.value = currentState;
    }
  });
  vue.onBeforeUnmount(unsubscribe);
  return vue.computed(() => selector.value);
};

const useDispatch = () => {
  const {
    dispatch
  } = useStore();
  return dispatch;
};

exports.ReduxStore = ReduxStore;
exports.useDispatch = useDispatch;
exports.useSelector = useSelector;
exports.useStore = useStore;
//# sourceMappingURL=index.js.map
