import { computed, onBeforeUnmount, ref } from 'vue';
import { useStore } from "./useStore.js";
export const useSelector = (select, equalityFn = (nextState, currentState) => nextState === currentState) => {
  const {
    subscribe,
    getState
  } = useStore();
  const selector = ref(select(getState()));
  let currentState;
  const unsubscribe = subscribe(() => {
    const nextState = select(getState());

    if (!equalityFn(nextState, currentState)) {
      currentState = nextState;
      selector.value = currentState;
    }
  });
  onBeforeUnmount(unsubscribe);
  return computed(() => selector.value);
};