import { inject, ref, onBeforeUnmount, computed } from 'vue';

const ReduxStore = Symbol('redux');

const useStore = () => inject(ReduxStore);

const useSelector = (select, equalityFn = (nextState, currentState) => nextState === currentState) => {
  const {
    subscribe,
    getState
  } = useStore();
  const selector = ref(select(getState()));
  let currentState;
  const unsubscribe = subscribe(() => {
    const nextState = select(getState());

    if (!equalityFn(nextState, currentState)) {
      currentState = nextState;
      selector.value = currentState;
    }
  });
  onBeforeUnmount(unsubscribe);
  return computed(() => selector.value);
};

const useDispatch = () => {
  const {
    dispatch
  } = useStore();
  return dispatch;
};

export { ReduxStore, useDispatch, useSelector, useStore };
//# sourceMappingURL=index.js.map
